# gds-psuu

Parameter space search under uncertainty for the GDS ecosystem.

Built on top of [gds-sim](https://github.com/BlockScience/gds-core), `gds-psuu` provides a search engine for intelligently exploring simulation parameter spaces to optimize KPIs.
